@@ -10,10 +10,8 @@
 #include <KAboutData>
 #include <KCrash>
 #include <KLocalizedString>
-#include <Kdelibs4ConfigMigrator>
 #include <QApplication>
 #include <QCommandLineParser>
-#include <QDBusConnection>
 
 #include "kiten.h"
 #include "kiten_version.h"
@@ -26,15 +24,7 @@ int main(int argc, char *argv[])
 {
     //   qInstallMsgHandler(noMessageOutput);	//Disable Qt Errors from showing
 
-    // Copyright and author information
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("kiten"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("kitenrc"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("kitenui.rc"));
-    migrate.migrate();
-
     KLocalizedString::setApplicationDomain("kiten");
-    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
 
     QApplication app(argc, argv);
 
@@ -48,7 +38,7 @@ int main(int argc, char *argv[])
                               "(c) 2006-2008, Joseph Kerian\n"
                               "(c) 2011, Daniel E. Moctezuma"),
                          QString(),
-                         QStringLiteral("https://edu.kde.org/kiten"));
+                         QStringLiteral("https://apps.kde.org/kiten"));
 
     aboutData.addAuthor(i18n("Jason Katz-Brown"), i18n("Original author"), QStringLiteral("jason@katzbrown.com"));
     aboutData.addCredit(i18n("Jim Breen"),
@@ -65,7 +55,7 @@ int main(int argc, char *argv[])
                              "polishing and simplification"),
                         QStringLiteral("democtezuma@gmail.com"));
 
-    aboutData.setOrganizationDomain("kde.org"); // Set this for the DBUS ID
+    aboutData.setOrganizationDomain("kde.org");
 
 #ifdef Q_OS_WIN
     QApplication::setStyle(QStringLiteral("breeze"));
@@ -81,13 +71,7 @@ int main(int argc, char *argv[])
     aboutData.processCommandLine(&parser);
 
     auto kiten = new Kiten();
-
-    // Register the DBUS name or die
-    if (!QDBusConnection::sessionBus().registerService(QStringLiteral("org.kde.kiten"))) {
-        exit(1);
-    }
-
     kiten->show();
-    QDBusConnection::sessionBus().registerObject(QStringLiteral("/"), kiten, QDBusConnection::ExportAllSlots);
+
     return app.exec();
 }
